@@ -1,11 +1,14 @@
 #modified 6/6/20 to vectorize the labels and rectangles.
 #modified 8/19/22 to make labels characters (which they are normally)
 "iclust.diagram" <- 
-function(ic,labels=NULL,short=FALSE,digits=2,cex=NULL,min.size=NULL,e.size=1,colors=c("black","blue"), main="ICLUST diagram",cluster.names = NULL,marg=c(.5,.5,1.5,.5),plot=TRUE,bottomup=TRUE) {
+function(ic,labels=NULL,short=FALSE,digits=2,cex=NULL,min.size=NULL,e.size=1,colors=c("black","blue"), main="ICLUST diagram",
+      cluster.names = NULL,marg=c(.5,.5,1.5,.5),plot=TRUE,bottomup=TRUE,both=TRUE) {
 
   old.par<- par(mar=marg)  #give the window some narrower margins
   on.exit(par(old.par))  #set them back
 
+
+                               
 clusters <- ic$results  #the main table from ICLUST 
 num <- nrow(clusters)
 num.var <- num+1
@@ -91,6 +94,7 @@ for(clust in 1:nc) {
 
 rect.mat <- matrix(unlist(rect.list),ncol=12,byrow=TRUE)
 rect.df <- as.data.frame(rect.mat,stringsAsFactors=FALSE)
+
 colnames(rect.df ) <- c("left","y","right","right.y","topx","topy", "xbott","botty","centerx","centery","radius","lab")
 
 if(plot) {
@@ -103,7 +107,7 @@ cluster.df <- data.frame(cluster.mat,stringsAsFactors=FALSE)
 cluster.df[c(1:12,14:15)] <- nchar2numeric(cluster.df[c(1:12,14:15)])
 colnames(cluster.df ) <- c("left","yl","right","yr","topx","topy","xbott","botty","centerx","centery","link","radius","lab","alpha","beta")
 rownames(cluster.df) <- cluster.df$lab
-dia.cluster1(cluster.df,cex=cex,e.size=e.size, digits=digits)
+dia.cluster1(cluster.df,cex=cex,e.size=e.size, digits=digits,both = both)
 
 
 arrow.mat <- matrix(unlist(arrow.list),ncol=21,byrow=TRUE)
@@ -117,7 +121,7 @@ text(tv[,1],tv[,2],tv[,3],cex=tv[,5])
       arrows(x0=tv[,6],y0=tv[,7],x1=tv[,8],y1=tv[,9],length=tv[1,10],angle=tv[1,11],code=1,col=tv[,20],lty=tv[,21])
         arrows(x0=tv[,13],y0=tv[,14],x1=tv[,15],y1=tv[,16],length=tv[1,17],angle=tv[1,18],code=2,col=tv[,20],lty=tv[,21])
 }  #end of plot
-sorted.order <-  psychTools::dfOrder(data.frame(y=as.numeric(rect.df[,"y"]), lab= rect.df[,"lab"]),ascending=TRUE)[,"lab"]
+sorted.order <-  dfOrder(data.frame(y=as.numeric(rect.df[,"y"]), lab= rect.df[,"lab"]),ascending=TRUE)[,"lab"]
 invisible(sorted.order)
 }   #end of iclust.diagram
 
@@ -182,8 +186,17 @@ invisible(sorted.order)
   #still a little slow, but better than before
   # By putting NA at the end of every unit.circle, we can draw multiple circles rapidly
   #modified 8/21/22 to include "beta"
+  #modified 6//15/24 to allow plotting both, alpha or beta 
  "dia.cluster1" <- 
- function(cluster.df,digits=2,cex = cex,e.size=.6,xlim=c(0,1),ylim=c(0,1)) {
+ function(cluster.df,digits=2,cex = cex,e.size=.6,xlim=c(0,1),ylim=c(0,1),both=TRUE) {
+ 
+ if(both==TRUE) {draw.alpha<- TRUE
+          draw.beta <- TRUE} else {
+          if(both == "alpha")  {draw.alpha <- TRUE
+                               draw.beta <- FALSE}  else {
+                               draw.alpha <- FALSE
+                               draw.beta <- TRUE}
+                               }
  
     big <- cluster.df[!is.na(cluster.df[,"alpha"]),]
    
@@ -198,13 +211,21 @@ invisible(sorted.order)
 	 #these next two lines just report the first values
 	 temp.alpha <- substitute(list(alpha) == "")
 	 temp.beta <- substitute(list(beta) == "")
-	 text(x.big,y.big,temp.alpha,cex=cex,adj=1)  #this shows the symbol alpha to the left
-	 text(x.big,y.big,temp.beta, cex=cex,adj=c(1,1.5))  #below and to the left 
+	 if(both==TRUE | both == "both") {   #draw them both
+	       text(x.big,y.big,temp.alpha,cex=cex,adj=1)  #this shows the symbol alpha to the left
+	                 text(x.big,y.big,round(big[,"alpha"],digits),offset=1,adj=0,cex=cex)
+	       text(x.big,y.big,temp.beta, cex=cex,adj=c(1,1.5))  #below and to the left 
+	                text(x.big,y.big,round(big[,"beta"],digits),cex=cex,adj=c(0,1.7))
+	    } else {if(draw.alpha) {text(x.big,y.big,temp.alpha,cex=cex,adj=1)  #this shows the symbol alpha to the left
+	                 text(x.big,y.big,round(big[,"alpha"],digits),offset=1,adj=0,cex=cex)
+	                 } else {text(x.big,y.big,temp.beta, cex=cex,adj=1)  #below and to the left 
+	                text(x.big,y.big,round(big[,"beta"],digits),cex=cex,offset=1,adj=0)}} 
+	                 
+	
 	
-	 text(x.big,y.big,round(big[,"alpha"],digits),offset=1,adj=0,cex=cex)
 	 #	 text(x.big,y.big,round(big[,"beta"],digits),cex=cex,pos=1)
      #text(x.big,y.big,round(big[,"beta"],digits),cex=cex,pos=1)
-          text(x.big,y.big,round(big[,"beta"],digits),cex=cex,adj=c(0,1.7))
+        
 	 #text(x.big,y.big, substitute(list(alpha) == list(a),list(a=round(big[,"alpha"],digits))),cex=cex) 
 	 #text(x.big,y.big, substitute(list(beta) == list(b), list(b=round(big[,"beta"],digits))),cex=cex,pos=1) 
 	# temp.n <- NROW(big)
