@@ -238,7 +238,7 @@ organize.results <- function(result,x=NA,n.iter=1,p.keyed=.9,dictionary=NULL,wtd
 
 #items [[criteria[j] ]] <-  cbind(replicated.items[[j]],Freq=Freq,mean.r=means,sd.r = sds,dictionary[names(replicated.items[[j]]),])
     items[[criteria[j]]] <-  cbind(Freq,mean.r = means,sd.r = sds,dictionary[names(rep.item),,drop=FALSE])
-	items[[criteria[j]]] <- psychTools::dfOrder(items [[criteria[j] ]],"-mean.r",absolute=TRUE) #sort on the mean.r column
+	items[[criteria[j]]] <- dfOrder(items [[criteria[j] ]],"-mean.r",absolute=TRUE) #sort on the mean.r column
 #	items[[criteria[j]]] <- items[[criteria[j]]][items[[criteria[j]]][,"Freq"] >= n.iter * p.keyed,]
 	
 	#now prepare the best.keys list
@@ -538,11 +538,12 @@ key.value <- function(key,r) {
 	 return(result)
 	}
 
-#
+#added the test for length>1 for the null case   4/16/23
 create.ordered.key <- function(x) {
+  if(length(x)>1 ){
   for (i in 1: length(x)) {
    if(sign(x[i])<0 ) rownames(x)[i] <- paste0("-",rownames(x)[i])
-   }
+   }}
    return(rownames(x))
      }
     
@@ -570,7 +571,7 @@ create.ordered.key <- function(x) {
      return(item.nums)
          }     
     
-predict.bestScales <- function(object,data,new.data) 
+predict_bestScales <- function(object,data,new.data) 
 {keys <- object$keys
 if (is.null(keys)){ keys<- object$key.list
  keys <- make.keys(data,keys) }  
@@ -585,7 +586,7 @@ return(predicted)
 
 
 #does not do what I want
-predict.wtdScales <- function(object,data,new.data) 
+predict_wtdScales <- function(object,data,new.data) 
 {weights <- object$weights
   
 stats <- describe(data,fast=TRUE,ranges=FALSE)
@@ -599,7 +600,7 @@ return(predicted)
 #####
 #print.psych.bestscales is called from the psych.print function
 
-print.psych.bestScales <- function(x,digits=2,short=NULL,...) {
+print_psych.bestScales <- function(x,digits=2,short=NULL,...) {
    cat("\nCall = ")
    print(x$Call)
 if(!is.null(x$items)) {
@@ -616,10 +617,19 @@ if(!is.null(x$items)) {
    cat("\n Best items on each scale with counts of replications\n")    
  for(i in 1:nvar) {
  cat("\n Criterion = ",names(items[i]),"\n")
+ 
+ 
   if(length(items[[i]]) > 3) {
  temp <- data.frame(items[[i]])
-   temp[2:3] <- round(temp[2:3],digits)} else{temp <- items[[i]]
+ if("item" %in% colnames(temp)) {item.loc <- which(colnames(temp)=="item")
+                                colnames(temp)[item.loc] <- "Item" } #added 5/13/24
    temp[2:3] <- round(temp[2:3],digits)
+   temp["Item"]  <- format(temp["Item"], justify="left")
+   } else{temp <- items[[i]]
+     if("item" %in% colnames(temp)) {item.loc <- which(colnames(temp)=="item")
+                                colnames(temp)[item.loc] <- "Item" } #added 5/13/24
+   temp[2:3] <- round(temp[2:3],digits)
+   temp["Item"]  <- format(temp["Item"], justify="left")
   }
    print(temp)  
  }} else {
@@ -628,10 +638,14 @@ if(!is.null(x$items)) {
  for(i in 1:nvar) {
  cat("\n Criterion = ",names(items[i]),"\n")
   temp <- data.frame(items[[i]])
+   if("item" %in% colnames(temp)) colnames(temp)["item"] <- "Item"  #added 5/13/24
   temp <- temp[-1]
   if(length(items[[i]]) > 3) {
-   temp[1:3] <- round(temp[1:3],digits)} else{temp <- items[[i]]
    temp[1:3] <- round(temp[1:3],digits)
+   temp["Item"] <- format(temp["Item"],justify="left")
+    } else{temp <- items[[i]]
+   temp[1:3] <- round(temp[1:3],digits)
+   temp["Item"] <- format(temp["Item"],justify="left")
   }
    print(temp)  
  }}
