@@ -19,9 +19,11 @@ function (x,group=NULL,mat=FALSE,type=3,digits=15,data=NULL,...) {
    group <- x[ps$x]} else {x <- data[ps$y]
    group <- data[ps$x]}
 } 
+
+ if((inherits(x[1], "data.frame", which=TRUE ) >1 )) x <- fix.dplyr(x)    #to get around a problem created by dplyr
  if(is.null(group)) {answer <- describe(x,type=type)
    warning("no grouping variable requested")} else {
-   x <- char2numeric(x)   #do this before doing by groups   4/16/23
+   x <- char2numeric(x,flag=FALSE)   #do this before doing by groups   4/16/23
    if(!is.data.frame(group) && !is.list(group) && (length(group) < NROW(x))) group <- x[,group ,drop=FALSE]
 		answer <- by(x,group,describe,type=type,...)
 		answer <- fix.is.null(answer)
